summaryrefslogtreecommitdiffstats
path: root/src/combobutton.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/combobutton.h')
-rwxr-xr-xsrc/combobutton.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/src/combobutton.h b/src/combobutton.h
index 3f07199..f7c0d41 100755
--- a/src/combobutton.h
+++ b/src/combobutton.h
@@ -3,10 +3,10 @@
#ifndef COMBOBUTTON_H
#define COMBOBUTTON_H
-#include <qwidget.h>
+#include <tqwidget.h>
-class QString;
-class QPixmap;
+class TQString;
+class TQPixmap;
class KPushButton;
class KComboBox;
@@ -15,9 +15,10 @@ class KComboBox;
* @author Daniel Faust <[email protected]>
* @version 0.3
*/
-class ComboButton : public QWidget
+class ComboButton : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
enum SizeMode {
Min, Max
@@ -25,10 +26,10 @@ public:
/**
* Constructor
* @param parent The parent widget
* @param name The name of the file list
*/
- ComboButton( QWidget *parent, const char *name = 0 );
+ ComboButton( TQWidget *tqparent, const char *name = 0 );
/**
* Destructor
@@ -38,11 +39,11 @@ public:
/**
* Insert a new item with @p text at position @p index
*/
- void insertItem( const QString &text, int index = -1 );
+ void insertItem( const TQString &text, int index = -1 );
/**
* Insert a new item with an icon @p pixmap and @p text at position @p index
*/
- void insertItem( const QPixmap &pixmap, const QString &text, int index = -1 );
+ void insertItem( const TQPixmap &pixmap, const TQString &text, int index = -1 );
/**
* Increase the combobutton's height by @p height
@@ -62,12 +63,12 @@ public:
/**
* Sets the font of the combobutton
*/
- void setFont( const QFont& font );
+ void setFont( const TQFont& font );
/**
* Returns the font of the button
*/
- QFont font();
+ TQFont font();
private:
/** A pointer to the button */
@@ -83,10 +84,10 @@ private:
/** Recalculate the size of the combobutton */
void balanceSize();
/** The button gets a new label, etc. */
- void repaintButton();
+ void tqrepaintButton();
//public slots:
- //void setCurrentItem(const QString &item, bool insert=false, int index=-1);
+ //void setCurrentItem(const TQString &item, bool insert=false, int index=-1);
//void setCurrentItem(int index);
private slots:
@@ -25,10 +26,10 @@ public:
/**
* Constructor
- * @param parent The parent widget
+ * @param tqparent The tqparent widget
* @param name The name of the file list
*/